function md=balancedthickness(md)
%BALANCEDTHICKNESS - balancedthickness solution sequence.
%
%   Usage:
%      md=balancedthickness(md)

	%timing
	t1=clock;

	numanalyses=1;
	analyses=[BalancedThicknessAnalysisEnum];
	solution_type=BalancedthicknessSolutionEnum;

	displaystring(md.verbose,'%s',['create finite element model']);
	femmodel=NewFemModel(md,solution_type,analyses,numanalyses);

	%retrieve parameters
	verbose=femmodel.parameters.Verbose;
	qmu_analysis=femmodel.parameters.QmuAnalysis;

	%compute solution
	if ~qmu_analysis,
		displaystring(verbose,'%s',['call computational core']);
		femmodel=balancedthickness_core(femmodel);

		displaystring(verbose,'%s',['write results']);
		md.results.balancedthickness=OutputResults(femmodel.elements, femmodel.nodes , femmodel.vertices , femmodel.loads , femmodel.materials, femmodel.parameters, femmodel.results);
	else
		%launch dakota driver for diagnostic core solution
		Qmu(femmodel);
	end

	%stop timing
	t2=clock;
	displaystring(md.verbose,'\n%s\n',['solution converged in ' num2str(etime(t2,t1)) ' seconds']);
